@@ -29,7 +29,7 @@
 #'
 #' @name fit-workflow
 #' @export
-#' @examples
+#' @examplesIf rlang::is_installed("recipes")
 #' library(parsnip)
 #' library(recipes)
 #' library(magrittr)
@@ -56,9 +56,18 @@ fit.workflow <- function(object, data, ..., control = control_workflow()) {
   check_dots_empty()
 
   if (is_missing(data)) {
-    abort("`data` must be provided to fit a workflow.")
+    cli_abort("{.arg data} must be provided to fit a workflow.")
   }
 
+  if (is_sparse_matrix(data)) {
+    data <- sparsevctrs::coerce_to_sparse_tibble(
+      data,
+      call = rlang::caller_env(0)
+    )
+  }
+
+  object <- toggle_sparsity(object, data)
+
   workflow <- object
   workflow <- .fit_pre(workflow, data)
   workflow <- .fit_model(workflow, control)
@@ -96,7 +105,7 @@ fit.workflow <- function(object, data, ..., control = control_workflow()) {
 #' @name workflows-internals
 #' @keywords internal
 #' @export
-#' @examples
+#' @examplesIf rlang::is_installed("recipes")
 #' library(parsnip)
 #' library(recipes)
 #' library(magrittr)
@@ -172,9 +181,10 @@ validate_has_preprocessor <- function(x, ..., call = caller_env()) {
   if (!has_preprocessor) {
     message <- c(
       "The workflow must have a formula, recipe, or variables preprocessor.",
-      i = "Provide one with `add_formula()`, `add_recipe()`, or `add_variables()`."
+      i = "Provide one with {.fun add_formula}, {.fun add_recipe},
+           or {.fun add_variables}."
     )
-    abort(message, call = call)
+    cli_abort(message, call = call)
   }
 
   invisible(x)
@@ -188,9 +198,9 @@ validate_has_model <- function(x, ..., call = caller_env()) {
   if (!has_model) {
     message <- c(
       "The workflow must have a model.",
-      i = "Provide one with `add_model()`."
+      i = "Provide one with {.fun add_model}."
     )
-    abort(message, call = call)
+    cli_abort(message, call = call)
   }
 
   invisible(x)
@@ -211,7 +221,10 @@ finalize_blueprint <- function(workflow) {
   } else if (has_preprocessor_variables(workflow)) {
     finalize_blueprint_variables(workflow)
   } else {
-    abort("`workflow` should have a preprocessor at this point.", .internal = TRUE)
+    cli_abort(
+      "{.arg workflow} should have a preprocessor at this point.",
+      .internal = TRUE
+    )
   }
 }
 
@@ -231,10 +244,16 @@ finalize_blueprint_formula <- function(workflow) {
   intercept <- tbl_encodings$compute_intercept
 
   if (!is_string(indicators)) {
-    abort("`indicators` encoding from parsnip should be a string.", .internal = TRUE)
+    cli_abort(
+      "`indicators` encoding from parsnip should be a string.",
+      .internal = TRUE
+    )
   }
   if (!is_bool(intercept)) {
-    abort("`intercept` encoding from parsnip should be a bool.", .internal = TRUE)
+    cli_abort(
+      "`intercept` encoding from parsnip should be a bool.",
+      .internal = TRUE
+    )
   }
 
   # Use model specific information to construct the blueprint
@@ -252,7 +271,11 @@ pull_workflow_spec_encoding_tbl <- function(workflow) {
   spec <- extract_spec_parsnip(workflow)
   spec_cls <- class(spec)[[1]]
 
-  tbl_encodings <- parsnip::get_encoding(spec_cls)
+  if (modelenv::is_unsupervised_spec(spec)) {
+    tbl_encodings <- modelenv::get_encoding(spec_cls)
+  } else {
+    tbl_encodings <- parsnip::get_encoding(spec_cls)
+  }
 
   indicator_engine <- tbl_encodings$engine == spec$engine
   indicator_mode <- tbl_encodings$mode == spec$mode
@@ -261,7 +284,10 @@ pull_workflow_spec_encoding_tbl <- function(workflow) {
   out <- tbl_encodings[indicator_spec, , drop = FALSE]
 
   if (nrow(out) != 1L) {
-    abort("Exactly 1 model/engine/mode combination must be located.", .internal = TRUE)
+    cli_abort(
+      "Exactly 1 model/engine/mode combination must be located.",
+      .internal = TRUE
+    )
   }
 
   out
