@@ -1,3 +1,5 @@
+skip_if_not_installed("recipes")
+
 test_that("can add variables to a workflow", {
   wf <- workflow()
   wf <- add_variables(wf, y, c(x1, x2))
@@ -168,8 +170,7 @@ test_that("`outcomes` are removed from set of possible `predictors` (#72)", {
 
   workflow2 <- add_variables(workflow, mpg, mpg)
 
-  # vctrs subscript error
-  expect_error(.fit_pre(workflow2, mtcars))
+  expect_error(.fit_pre(workflow2, mtcars), class = "vctrs_error_subscript_oob")
 })
 
 test_that("selecting no `outcomes` doesn't break selection of `predictors`", {
